@@ -625,11 +625,14 @@ class Plot(AssetBlock):
 
     _tag = "Plot"
 
-    def __init__(self, data: t.Any, caption: t.Optional[str] = None, id: str = None, label: str = None):
+    def __init__(
+        self, data: t.Any, caption: t.Optional[str] = None, responsive: bool = True, id: str = None, label: str = None
+    ):
         """
         Args:
             data: The `plot` object to attach
             caption: A caption to display below the plot (optional)
+            responsive: Whether the plot should fit to its container dimensions (optional, default: True)
             id: A unique id for the block to aid querying (optional)
             label: A label used when displaying the block (optional)
         """
@@ -637,7 +640,9 @@ class Plot(AssetBlock):
         if out_fn.mime == PKL_MIMETYPE:
             raise DPError("Can't embed object as a plot")
 
-        super().__init__(file=out_fn.file, caption=caption, width=640, height=480, id=id, label=label)
+        super().__init__(
+            file=out_fn.file, caption=caption, width=640, height=480, id=id, label=label, responsive=responsive
+        )
 
 
 class Table(AssetBlock):
@@ -676,7 +681,6 @@ class DataTable(AssetBlock):
         self,
         df: pd.DataFrame,
         caption: t.Optional[str] = None,
-        can_pivot: bool = True,
         id: str = None,
         label: str = None,
     ):
@@ -684,14 +688,9 @@ class DataTable(AssetBlock):
         Args:
             df: The pandas dataframe to attach to the report
             caption: A caption to display below the plot (optional)
-            can_pivot: Is the table pivotable (not yet supported)
             id: A unique id for the block to aid querying (optional)
             label: A label used when displaying the block (optional)
-
-            ..hint:: `can_pivot` is currently unsupported and can be ignored
         """
         fn = save_df(df)
         (rows, columns) = df.shape
-        super().__init__(
-            file=fn.file, caption=caption, rows=rows, columns=columns, can_pivot=can_pivot, id=id, label=label
-        )
+        super().__init__(file=fn.file, caption=caption, rows=rows, columns=columns, id=id, label=label)
