@@ -20,10 +20,10 @@ from jinja2 import Environment, FileSystemLoader, Markup, Template, contextfunct
 from lxml import etree
 from lxml.etree import Element
 
-from datapane import __version__
-from datapane.client.api.common import DPTmpFile, Resource, do_download_file
+from datapane.client.api.common import DPTmpFile, Resource
 from datapane.client.api.dp_object import DPObjectRef
 from datapane.client.api.runtime import _report
+from datapane.client.utils import DPError
 from datapane.common import log, timestamp
 from datapane.common.report import local_report_def, validate_report_doc
 
@@ -33,33 +33,17 @@ local_post_xslt = etree.parse(str(local_report_def / "local_post_process.xslt"))
 local_post_transform = etree.XSLT(local_post_xslt)
 
 # only these types will be documented by default
-__all__ = ["Report", "Visibility"]
+__all__ = ["Report", "Visibility", "ReportType"]
 
 __pdoc__ = {
     "Report.endpoint": False,
 }
 
 
-@contextfunction
-def include_raw(ctx, name):
-    """ Normal jinja2 {% include %} doesn't escape {{...}} which appear in React's source code """
-    env = ctx.environment
-    return Markup(env.loader.get_source(env, name)[0])
-
-
-def is_jupyter() -> bool:
-    """Checks if inside ipython shell inside browser"""
-    try:
-        return get_ipython().__class__.__name__ == "ZMQInteractiveShell"  # noqa: F821
-    except Exception:
-        return False
-
-
 class Visibility(IntEnum):
     """The report visibility type"""
 
     PRIVATE = 0  # private to owner
-    ORG = 1  # visible to all users in the org
     PUBLIC = 2  # anon/unauthed access
 
 
@@ -71,41 +55,80 @@ class ReportType(Enum):
     ARTICLE = "article"
 
 
+SKIP_DISPLAY_MSG = False
+
+
+def is_jupyter() -> bool:
+    """Checks if inside ipython shell inside browser"""
+    try:
+        return get_ipython().__class__.__name__ == "ZMQInteractiveShell"  # noqa: F821
+    except Exception:
+        return False
+
+
+@contextfunction
+def include_raw(ctx, name):
+    """ Normal jinja2 {% include %} doesn't escape {{...}} which appear in React's source code """
+    env = ctx.environment
+    # Escape </script> to prevent 3rd party JS terminating the local report bundle.
+    # Note there's an extra "\" because it needs to be escaped at both the python and JS level
+    src = env.loader.get_source(env, name)[0].replace("</script>", "<\\\/script>")
+    return Markup(src)
+
+
 class ReportFileWriter:
     """ Collects data needed to display a local report, and generates the local HTML """
 
     template: t.Optional[Template] = None
     assets: Path
-    asset_url = "https://datapane.com/static"
-    asset_js = "local-report-base.css"
-    asset_css = "local-report-base.js"
+    dev_mode: bool = False
 
-    def _setup_template(self) -> Template:
+    def _setup_template(self):
         """ Jinja template setup for local rendering """
         # check we have the files, download if not
         self.assets = ir.files("datapane.resources.local_report")
-        if not (self.assets / self.asset_js).exists():
-            log.warning("Can't find report assets, downloading")
-            do_download_file(f"{self.asset_url}/{self.asset_js}", self.assets / self.asset_js)
-            do_download_file(f"{self.asset_url}/{self.asset_css}", self.assets / self.asset_css)
+        if not (self.assets / "local-report-base.css").exists():
+            raise DPError("Can't find local FE bundle - report.save not available, please install release version")
 
         template_loader = FileSystemLoader(self.assets)
         template_env = Environment(loader=template_loader)
         template_env.globals["include_raw"] = include_raw
         self.template = template_env.get_template("template.html")
 
-    def write(self, report_doc: str, path: str, report_type: ReportType, standalone: bool):
+    def _display_msg(self):
+        global SKIP_DISPLAY_MSG
+
+        if SKIP_DISPLAY_MSG:
+            return None
+        else:
+            SKIP_DISPLAY_MSG = False
+
+        if is_jupyter():
+            from IPython.display import Markdown, display
+
+            display(
+                Markdown(
+                    "Thanks for using **Datapane**, to automate and securely share reports in your organization see [Datapane Enterprise](https://datapane.com/enterprise/)"
+                )
+            )
+        else:
+            print(
+                "Thanks for using Datapane, to automate and securely share reports in your organization see Datapane Enterprise - https://datapane.com/enterprise/"
+            )
+
+    def write(self, report_doc: str, path: str, report_type: ReportType):
+
         # create template on demand
         if not self.template:
             self._setup_template()
 
+        self._display_msg()
+
         # template.html inlines the report doc with backticks so we need to escape any inside the doc
         report_doc_esc = report_doc.replace("`", r"\`")
         r = self.template.render(
             report_doc=report_doc_esc,
             report_type=report_type,
-            standalone=standalone,
-            cdn_base=f"https://storage.googleapis.com/datapane-public/report-assets/{__version__}",
         )
         Path(path).write_text(r, encoding="utf-8")
 
@@ -125,7 +148,7 @@ class Report(DPObjectRef):
     _tmp_report: t.Optional[Path] = None  # Temp local report
     _local_writer = ReportFileWriter()
     report_type: ReportType = ReportType.REPORT
-    list_fields: t.List[str] = ["name", "web_url", "versions"]
+    list_fields: t.List[str] = ["name", "web_url", "group"]
     """When set, the report is full-width suitable for use in a dashboard"""
 
     def __init__(
@@ -200,6 +223,7 @@ class Report(DPObjectRef):
         visibility: t.Optional[Visibility] = None,
         open: bool = False,
         tags: t.List[str] = None,
+        group: t.Optional[str] = None,
         **kwargs,
     ) -> None:
         """
@@ -209,7 +233,7 @@ class Report(DPObjectRef):
             name: The report name - can include spaces, caps, symbols, etc., e.g. "Profit & Loss 2020"
             description: A high-level description for the report, this is displayed in searches and thumbnails
             source_url: A URL pointing to the source code for the report, e.g. a GitHub repo or a Colab notebook
-            visibility: one of `"PUBLIC"` _(default on Public)_, `"ORG"` _(Teams only)_, or `"PRIVATE"` _(limited on Public, unlimited on Teams)_
+            visibility: one of `"PUBLIC"` _(default on Public)_, or `"PRIVATE"` _(limited on Public, unlimited on Teams)_
             open: Open the file in your browser after creating
             tags: A list of tags (as strings) used to categorise your report
         """
@@ -224,7 +248,9 @@ class Report(DPObjectRef):
             warnings.warn("Passing visibility as a string is deprecated, use dp.Visibility enum instead.")
         else:
             visibility_str = glom(visibility, "name", default=None)
-        kwargs.update(name=name, description=description, tags=tags, source_url=source_url, visibility=visibility_str)
+        kwargs.update(
+            name=name, description=description, tags=tags, source_url=source_url, visibility=visibility_str, group=group
+        )
 
         report_str, attachments = self._gen_report(embedded=False, title=name, description=description)
         res = Resource(self.endpoint).post_files(dict(attachments=attachments), document=report_str, **kwargs)
@@ -239,19 +265,18 @@ class Report(DPObjectRef):
             webbrowser.open_new_tab(self.web_url)
         print(f"Report successfully published at {self.web_url}")
 
-    def save(self, path: str, open: bool = False, standalone: bool = False) -> None:
+    def save(self, path: str, open: bool = False) -> None:
         """Save the report to a local HTML file
 
         Args:
             path: location to save the HTML file
             open: Open the file in your browser after creating
-            standalone: Create a fully standalone HTML report with minimal external/network dependencies _(this can result in large files)_
         """
         self._last_saved = path
 
         local_doc, _ = self._gen_report(embedded=True, title="Local Report", description="Description")
 
-        self._local_writer.write(local_doc, path, self.report_type, standalone)
+        self._local_writer.write(local_doc, path, self.report_type)
 
         if open:
             path_uri = f"file://{osp.realpath(osp.expanduser(path))}"
