@@ -11,6 +11,7 @@ from .dp_types import (
     PKL_MIMETYPE,
     SECS_1_HOUR,
     SECS_1_WEEK,
+    TD_1_DAY,
     TD_1_HOUR,
     URL,
     EnumType,
@@ -23,4 +24,11 @@ from .dp_types import (
     get_dp_mode,
     set_dp_mode,
 )
-from .utils import guess_type, log, log_command, _setup_dp_logging, temp_fname, timestamp
+from .utils import (
+    guess_type,
+    log,
+    log_command,
+    _setup_dp_logging,
+    temp_fname,
+    timestamp,
+)
